@@ -1,5 +1,14 @@
 from sqlbean.db.query import escape
 from sqlbean.db.connection import get_db_by_table
+
+@classmethod
+def get_or_create(cls, **kwds):
+    ins = cls.get(**kwds)
+    if ins is None:
+        ins = cls(**kwds)
+    return ins
+
+
 def lower_name(class_name):
     """
     >>>lower_name("UserCount")
