@@ -1,6 +1,6 @@
 #coding:utf-8
 from sqlbean.db.query import Query, escape
-from sqlbean.metamodel import cache, lower_name, ModelBase
+from sqlbean.metamodel import cache, lower_name, ModelBase,get_or_create
 
 class Model(object):
     '''
@@ -267,6 +267,8 @@ class Model(object):
             self._update()
         return self
 
+    get_or_create = get_or_create
+
     @classmethod
     def replace_into(cls, **kwds):
         pk = cls.Meta.pk
